
/**
 *  @file mapsystemattrsize.C
 *
 *  @brief Interface to get the map of system target attributes with respective
 *  attribute size
 */

// STD
#include <map>

// TARG
#include <mapsystemattrsize.H>


//******************************************************************************
// Macros
//******************************************************************************

#undef TARG_NAMESPACE
#undef TARG_CLASS
#undef TARG_FUNC

//******************************************************************************
// Implementation
//******************************************************************************

namespace TARGETING
{


#define TARG_NAMESPACE "TARGETING::"
#define TARG_CLASS "MapSystemAttrSize::"

//******************************************************************************
// TARGETING::mapSystemAttrSize
//******************************************************************************

TARGETING::MapSystemAttrSize& mapSystemAttrSize()
{
    #define TARG_FN "mapSystemAttrSize()"

    return TARG_GET_SINGLETON(TARGETING::theMapSystemAttrSize);

    #undef TARG_FN
}

//******************************************************************************
// TARGETING::MapSystemAttrSize::~MapSystemAttrSize
//******************************************************************************

MapSystemAttrSize::~MapSystemAttrSize()
{
    #define TARG_FN "~MapSystemAttrSize()"
    #undef TARG_FN
}

//******************************************************************************
// TARGETING::MapSystemAttrSize::getMapForWriteableSystemAttributes
//******************************************************************************

const AttrSizeMapper&
MapSystemAttrSize::getMapForWriteableSystemAttributes() const
{
    #define TARG_FN "getMapForWriteableSystemAttributes()"
    TARG_ENTER();

    TARG_EXIT();
    return iv_mapSysAttrSize;

    #undef TARG_FN
}

//******************************************************************************
// TARGETING::MapSystemAttrSize::MapSystemAttrSize
//******************************************************************************

MapSystemAttrSize::MapSystemAttrSize()
{
    #define TARG_FN "MapSystemAttrSize()"

    iv_mapSysAttrSize[ATTR_SCRATCH_UINT8_ARRAY_2] = sizeof(ATTR_SCRATCH_UINT8_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_FREQ_MCA_MHZ] = sizeof(ATTR_FREQ_MCA_MHZ_type);
    iv_mapSysAttrSize[ATTR_FORCE_SRAM_MMIO_OVER_I2C] = sizeof(ATTR_FORCE_SRAM_MMIO_OVER_I2C_type);
    iv_mapSysAttrSize[ATTR_XSCOM_BASE_ADDRESS] = sizeof(ATTR_XSCOM_BASE_ADDRESS_type);
    iv_mapSysAttrSize[ATTR_OCC_CONTROL_DATA] = sizeof(ATTR_OCC_CONTROL_DATA_type);
    iv_mapSysAttrSize[ATTR_SLCA_INDEX] = sizeof(ATTR_SLCA_INDEX_type);
    iv_mapSysAttrSize[ATTR_IS_SIMULATION] = sizeof(ATTR_IS_SIMULATION_type);
    iv_mapSysAttrSize[ATTR_PHYS_PRES_ASSERTED] = sizeof(ATTR_PHYS_PRES_ASSERTED_type);
    iv_mapSysAttrSize[ATTR_ENABLED_THREADS] = sizeof(ATTR_ENABLED_THREADS_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT64_2] = sizeof(ATTR_SCRATCH_INT64_2_type);
    iv_mapSysAttrSize[ATTR_MRW_DDR3_VDDR_MAX_LIMIT_POST_DRAM_INIT] = sizeof(ATTR_MRW_DDR3_VDDR_MAX_LIMIT_POST_DRAM_INIT_type);
    iv_mapSysAttrSize[ATTR_LPC_BUS_ADDR] = sizeof(ATTR_LPC_BUS_ADDR_type);
    iv_mapSysAttrSize[ATTR_HTMGT_INTERNAL_FLAGS] = sizeof(ATTR_HTMGT_INTERNAL_FLAGS_type);
    iv_mapSysAttrSize[ATTR_TEST_NO_DEFAULT_STRING] = sizeof(ATTR_TEST_NO_DEFAULT_STRING_type);
    iv_mapSysAttrSize[ATTR_SAVED_STATE_UINT8] = sizeof(ATTR_SAVED_STATE_UINT8_type);
    iv_mapSysAttrSize[ATTR_MEM_PORT_POS_OF_FAIL_THROTTLE] = sizeof(ATTR_MEM_PORT_POS_OF_FAIL_THROTTLE_type);
    iv_mapSysAttrSize[ATTR_HUGE_PAGE_SIZE] = sizeof(ATTR_HUGE_PAGE_SIZE_type);
    iv_mapSysAttrSize[ATTR_FABRIC_PRESENT_GROUPS] = sizeof(ATTR_FABRIC_PRESENT_GROUPS_type);
    iv_mapSysAttrSize[ATTR_PM_RESET_FFDC_ENABLE] = sizeof(ATTR_PM_RESET_FFDC_ENABLE_type);
    iv_mapSysAttrSize[ATTR_MSS_CAL_ABORT_ON_ERROR] = sizeof(ATTR_MSS_CAL_ABORT_ON_ERROR_type);
    iv_mapSysAttrSize[ATTR_CDM_POLICIES] = sizeof(ATTR_CDM_POLICIES_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT16_ARRAY_1] = sizeof(ATTR_SCRATCH_UINT16_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_PIB_I2C_REFCLOCK] = sizeof(ATTR_PIB_I2C_REFCLOCK_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT64_ARRAY_1] = sizeof(ATTR_SCRATCH_INT64_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_PROC_EPS_GB_PERCENTAGE] = sizeof(ATTR_PROC_EPS_GB_PERCENTAGE_type);
    iv_mapSysAttrSize[ATTR_MSS_VOLT_DDR4_VDDR_INTERCEPT_POST_DRAM_INIT] = sizeof(ATTR_MSS_VOLT_DDR4_VDDR_INTERCEPT_POST_DRAM_INIT_type);
    iv_mapSysAttrSize[ATTR_HDAT_HBRT_NUM_SECTIONS] = sizeof(ATTR_HDAT_HBRT_NUM_SECTIONS_type);
    iv_mapSysAttrSize[ATTR_HWAS_STATE_CHANGED_FLAG] = sizeof(ATTR_HWAS_STATE_CHANGED_FLAG_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT8_1] = sizeof(ATTR_SCRATCH_INT8_1_type);
    iv_mapSysAttrSize[ATTR_PHYP_SYSTEM_TYPE] = sizeof(ATTR_PHYP_SYSTEM_TYPE_type);
    iv_mapSysAttrSize[ATTR_DRTM_PAYLOAD_ADDR_MB_HB] = sizeof(ATTR_DRTM_PAYLOAD_ADDR_MB_HB_type);
    iv_mapSysAttrSize[ATTR_RECONFIGURE_LOOP] = sizeof(ATTR_RECONFIGURE_LOOP_type);
    iv_mapSysAttrSize[ATTR_SOCKET_POWER_TURBO] = sizeof(ATTR_SOCKET_POWER_TURBO_type);
    iv_mapSysAttrSize[ATTR_ISTEP_PAUSE_CONFIG] = sizeof(ATTR_ISTEP_PAUSE_CONFIG_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT16_ARRAY_2] = sizeof(ATTR_SCRATCH_UINT16_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_RECONFIG_LOOP_TESTS] = sizeof(ATTR_RECONFIG_LOOP_TESTS_type);
    iv_mapSysAttrSize[ATTR_PHYS_PRES_REQUEST_OPEN_WINDOW] = sizeof(ATTR_PHYS_PRES_REQUEST_OPEN_WINDOW_type);
    iv_mapSysAttrSize[ATTR_IPC_NODE_BUFFER_GLOBAL_ADDRESS] = sizeof(ATTR_IPC_NODE_BUFFER_GLOBAL_ADDRESS_type);
    iv_mapSysAttrSize[ATTR_PROC_EPS_READ_CYCLES_T0] = sizeof(ATTR_PROC_EPS_READ_CYCLES_T0_type);
    iv_mapSysAttrSize[ATTR_PROC_FABRIC_ASYNC_SAFE_MODE] = sizeof(ATTR_PROC_FABRIC_ASYNC_SAFE_MODE_type);
    iv_mapSysAttrSize[ATTR_SYSTEM_RESCLK_DISABLE] = sizeof(ATTR_SYSTEM_RESCLK_DISABLE_type);
    iv_mapSysAttrSize[ATTR_HOSTSVC_PLID] = sizeof(ATTR_HOSTSVC_PLID_type);
    iv_mapSysAttrSize[ATTR_PLCK_IPL_ATTR_OVERRIDES_EXIST] = sizeof(ATTR_PLCK_IPL_ATTR_OVERRIDES_EXIST_type);
    iv_mapSysAttrSize[ATTR_IS_DRTM_MPIPL_HB] = sizeof(ATTR_IS_DRTM_MPIPL_HB_type);
    iv_mapSysAttrSize[ATTR_MRW_DDR4_VDDR_MAX_LIMIT_POST_DRAM_INIT] = sizeof(ATTR_MRW_DDR4_VDDR_MAX_LIMIT_POST_DRAM_INIT_type);
    iv_mapSysAttrSize[ATTR_ATTN_CHK_ALL_PROCS] = sizeof(ATTR_ATTN_CHK_ALL_PROCS_type);
    iv_mapSysAttrSize[ATTR_OS_IPL_MODE] = sizeof(ATTR_OS_IPL_MODE_type);
    iv_mapSysAttrSize[ATTR_FREQ_CORE_MAX] = sizeof(ATTR_FREQ_CORE_MAX_type);
    iv_mapSysAttrSize[ATTR_CLEAR_DIMM_SPD_ENABLE] = sizeof(ATTR_CLEAR_DIMM_SPD_ENABLE_type);
    iv_mapSysAttrSize[ATTR_IPL_ATTRIBUTES] = sizeof(ATTR_IPL_ATTRIBUTES_type);
    iv_mapSysAttrSize[ATTR_PNOR_FLASH_WORKAROUNDS] = sizeof(ATTR_PNOR_FLASH_WORKAROUNDS_type);
    iv_mapSysAttrSize[ATTR_PROC_FABRIC_CORE_CEILING_RATIO] = sizeof(ATTR_PROC_FABRIC_CORE_CEILING_RATIO_type);
    iv_mapSysAttrSize[ATTR_HB_HRMOR_NODAL_BASE] = sizeof(ATTR_HB_HRMOR_NODAL_BASE_type);
    iv_mapSysAttrSize[ATTR_TPM_REQUIRED] = sizeof(ATTR_TPM_REQUIRED_type);
    iv_mapSysAttrSize[ATTR_RAW_MTM] = sizeof(ATTR_RAW_MTM_type);
    iv_mapSysAttrSize[ATTR_SYSTEM_CORECACHE_SKEWADJ_DISABLE] = sizeof(ATTR_SYSTEM_CORECACHE_SKEWADJ_DISABLE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT16_ARRAY_2] = sizeof(ATTR_SCRATCH_INT16_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT64_1] = sizeof(ATTR_SCRATCH_INT64_1_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT64_2] = sizeof(ATTR_SCRATCH_UINT64_2_type);
    iv_mapSysAttrSize[ATTR_FREQ_X_MHZ] = sizeof(ATTR_FREQ_X_MHZ_type);
    iv_mapSysAttrSize[ATTR_CUMULATIVE_PMCOMPLEX_RESET_COUNT] = sizeof(ATTR_CUMULATIVE_PMCOMPLEX_RESET_COUNT_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT32_2] = sizeof(ATTR_SCRATCH_UINT32_2_type);
    iv_mapSysAttrSize[ATTR_RISK_LEVEL_ORIGIN] = sizeof(ATTR_RISK_LEVEL_ORIGIN_type);
    iv_mapSysAttrSize[ATTR_MC_PLL_BUCKET] = sizeof(ATTR_MC_PLL_BUCKET_type);
    iv_mapSysAttrSize[ATTR_RUN_MAX_MEM_PATTERNS] = sizeof(ATTR_RUN_MAX_MEM_PATTERNS_type);
    iv_mapSysAttrSize[ATTR_MNFG_FLAGS] = sizeof(ATTR_MNFG_FLAGS_type);
    iv_mapSysAttrSize[ATTR_MSS_VOLT_DDR3_VDDR_SLOPE_POST_DRAM_INIT] = sizeof(ATTR_MSS_VOLT_DDR3_VDDR_SLOPE_POST_DRAM_INIT_type);
    iv_mapSysAttrSize[ATTR_DPO_MIN_FREQ_PERCENT] = sizeof(ATTR_DPO_MIN_FREQ_PERCENT_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT16_1] = sizeof(ATTR_SCRATCH_UINT16_1_type);
    iv_mapSysAttrSize[ATTR_PRESERVE_MDC_PARTITION_VPD] = sizeof(ATTR_PRESERVE_MDC_PARTITION_VPD_type);
    iv_mapSysAttrSize[ATTR_TEST_NEGATIVE_FCN] = sizeof(ATTR_TEST_NEGATIVE_FCN_type);
    iv_mapSysAttrSize[ATTR_CALCULATED_PROC_MEMORY_POWER_DROP] = sizeof(ATTR_CALCULATED_PROC_MEMORY_POWER_DROP_type);
    iv_mapSysAttrSize[ATTR_MSS_VCCD_OVERRIDE] = sizeof(ATTR_MSS_VCCD_OVERRIDE_type);
    iv_mapSysAttrSize[ATTR_HTMGT_PMCOMPLEX_RESET_COUNT_TIMER] = sizeof(ATTR_HTMGT_PMCOMPLEX_RESET_COUNT_TIMER_type);
    iv_mapSysAttrSize[ATTR_SMF_ENABLED] = sizeof(ATTR_SMF_ENABLED_type);
    iv_mapSysAttrSize[ATTR_MAX_INTERLEAVE_GROUP_SIZE] = sizeof(ATTR_MAX_INTERLEAVE_GROUP_SIZE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT32_ARRAY_2] = sizeof(ATTR_SCRATCH_INT32_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_NOMINAL_FREQ_MHZ] = sizeof(ATTR_NOMINAL_FREQ_MHZ_type);
    iv_mapSysAttrSize[ATTR_PM_GLOBAL_FIR_TRACE_EN] = sizeof(ATTR_PM_GLOBAL_FIR_TRACE_EN_type);
    iv_mapSysAttrSize[ATTR_MSS_VDDR_OVERIDE_SPD] = sizeof(ATTR_MSS_VDDR_OVERIDE_SPD_type);
    iv_mapSysAttrSize[ATTR_FUSED_CORE_MODE_HB] = sizeof(ATTR_FUSED_CORE_MODE_HB_type);
    iv_mapSysAttrSize[ATTR_SYNC_BETWEEN_STEPS] = sizeof(ATTR_SYNC_BETWEEN_STEPS_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT8_2] = sizeof(ATTR_SCRATCH_INT8_2_type);
    iv_mapSysAttrSize[ATTR_PROC_EPS_READ_CYCLES_T1] = sizeof(ATTR_PROC_EPS_READ_CYCLES_T1_type);
    iv_mapSysAttrSize[ATTR_WOF_POWER_LIMIT] = sizeof(ATTR_WOF_POWER_LIMIT_type);
    iv_mapSysAttrSize[ATTR_PIBMEM_REPAIR2] = sizeof(ATTR_PIBMEM_REPAIR2_type);
    iv_mapSysAttrSize[ATTR_SLCA_RID] = sizeof(ATTR_SLCA_RID_type);
    iv_mapSysAttrSize[ATTR_TEST_NULL_STRING] = sizeof(ATTR_TEST_NULL_STRING_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT8_ARRAY_1] = sizeof(ATTR_SCRATCH_UINT8_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_VLAN_SWITCHES] = sizeof(ATTR_VLAN_SWITCHES_type);
    iv_mapSysAttrSize[ATTR_PROC_EPS_WRITE_CYCLES_T2] = sizeof(ATTR_PROC_EPS_WRITE_CYCLES_T2_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT16_2] = sizeof(ATTR_SCRATCH_UINT16_2_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT32_1] = sizeof(ATTR_SCRATCH_UINT32_1_type);
    iv_mapSysAttrSize[ATTR_WOF_TABLE_LID_NUMBER] = sizeof(ATTR_WOF_TABLE_LID_NUMBER_type);
    iv_mapSysAttrSize[ATTR_FREQ_A_MHZ] = sizeof(ATTR_FREQ_A_MHZ_type);
    iv_mapSysAttrSize[ATTR_MSS_VOLT_DDR4_VDDR_SLOPE_POST_DRAM_INIT] = sizeof(ATTR_MSS_VOLT_DDR4_VDDR_SLOPE_POST_DRAM_INIT_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT32_1] = sizeof(ATTR_SCRATCH_INT32_1_type);
    iv_mapSysAttrSize[ATTR_EXP_MEM_PORT_POS_OF_FAIL_THROTTLE] = sizeof(ATTR_EXP_MEM_PORT_POS_OF_FAIL_THROTTLE_type);
    iv_mapSysAttrSize[ATTR_MAX_HSL_OPTICONNECT_CONNECTIONS] = sizeof(ATTR_MAX_HSL_OPTICONNECT_CONNECTIONS_type);
    iv_mapSysAttrSize[ATTR_PAYLOAD_KIND] = sizeof(ATTR_PAYLOAD_KIND_type);
    iv_mapSysAttrSize[ATTR_SYSTEM_BRAND_NAME] = sizeof(ATTR_SYSTEM_BRAND_NAME_type);
    iv_mapSysAttrSize[ATTR_BOOT_FLAGS] = sizeof(ATTR_BOOT_FLAGS_type);
    iv_mapSysAttrSize[ATTR_PAYLOAD_IN_MIRROR_MEM] = sizeof(ATTR_PAYLOAD_IN_MIRROR_MEM_type);
    iv_mapSysAttrSize[ATTR_HUGE_PAGE_COUNT] = sizeof(ATTR_HUGE_PAGE_COUNT_type);
    iv_mapSysAttrSize[ATTR_FABRIC_ADDR_EXTENSION_CHIP_ID] = sizeof(ATTR_FABRIC_ADDR_EXTENSION_CHIP_ID_type);
    iv_mapSysAttrSize[ATTR_EFFECTIVE_EC] = sizeof(ATTR_EFFECTIVE_EC_type);
    iv_mapSysAttrSize[ATTR_SYSTEM_IPL_PHASE] = sizeof(ATTR_SYSTEM_IPL_PHASE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT64_1] = sizeof(ATTR_SCRATCH_UINT64_1_type);
    iv_mapSysAttrSize[ATTR_HYP_DISPATCH_WHEEL] = sizeof(ATTR_HYP_DISPATCH_WHEEL_type);
    iv_mapSysAttrSize[ATTR_MSS_INTERLEAVE_ENABLE] = sizeof(ATTR_MSS_INTERLEAVE_ENABLE_type);
    iv_mapSysAttrSize[ATTR_ISTEP_MODE] = sizeof(ATTR_ISTEP_MODE_type);
    iv_mapSysAttrSize[ATTR_MSS_VMEM_REGULATOR_MAX_DIMM_COUNT] = sizeof(ATTR_MSS_VMEM_REGULATOR_MAX_DIMM_COUNT_type);
    iv_mapSysAttrSize[ATTR_PM_MALF_ALERT_ENABLE] = sizeof(ATTR_PM_MALF_ALERT_ENABLE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT8_2] = sizeof(ATTR_SCRATCH_UINT8_2_type);
    iv_mapSysAttrSize[ATTR_ISTEP_PAUSE_ENABLE] = sizeof(ATTR_ISTEP_PAUSE_ENABLE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT16_1] = sizeof(ATTR_SCRATCH_INT16_1_type);
    iv_mapSysAttrSize[ATTR_TEST_MAX_STRING] = sizeof(ATTR_TEST_MAX_STRING_type);
    iv_mapSysAttrSize[ATTR_FUSED_CORE_OPTION] = sizeof(ATTR_FUSED_CORE_OPTION_type);
    iv_mapSysAttrSize[ATTR_PIB_I2C_NEST_PLL] = sizeof(ATTR_PIB_I2C_NEST_PLL_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT64_ARRAY_2] = sizeof(ATTR_SCRATCH_INT64_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_DUMMY_RW] = sizeof(ATTR_DUMMY_RW_type);
    iv_mapSysAttrSize[ATTR_CME_STOP_PHANTOM_HALT_ENABLE] = sizeof(ATTR_CME_STOP_PHANTOM_HALT_ENABLE_type);
    iv_mapSysAttrSize[ATTR_NVDIMM_ENCRYPTION_KEYS_FW] = sizeof(ATTR_NVDIMM_ENCRYPTION_KEYS_FW_type);
    iv_mapSysAttrSize[ATTR_NVDIMM_ENCRYPTION_ENABLE] = sizeof(ATTR_NVDIMM_ENCRYPTION_ENABLE_type);
    iv_mapSysAttrSize[ATTR_PROC_EPS_WRITE_CYCLES_T1] = sizeof(ATTR_PROC_EPS_WRITE_CYCLES_T1_type);
    iv_mapSysAttrSize[ATTR_ORIG_FIR_SETTINGS_ACTION1] = sizeof(ATTR_ORIG_FIR_SETTINGS_ACTION1_type);
    iv_mapSysAttrSize[ATTR_FREQ_PB_MHZ_POUNDV_FALLBACK] = sizeof(ATTR_FREQ_PB_MHZ_POUNDV_FALLBACK_type);
    iv_mapSysAttrSize[ATTR_FREQ_PB_MHZ] = sizeof(ATTR_FREQ_PB_MHZ_type);
    iv_mapSysAttrSize[ATTR_PROC_EPS_READ_CYCLES_T2] = sizeof(ATTR_PROC_EPS_READ_CYCLES_T2_type);
    iv_mapSysAttrSize[ATTR_PGPE_PHANTOM_HALT_ENABLE] = sizeof(ATTR_PGPE_PHANTOM_HALT_ENABLE_type);
    iv_mapSysAttrSize[ATTR_HB_RSV_MEM_NEXT_SECTION] = sizeof(ATTR_HB_RSV_MEM_NEXT_SECTION_type);
    iv_mapSysAttrSize[ATTR_TEST_MIN_STRING] = sizeof(ATTR_TEST_MIN_STRING_type);
    iv_mapSysAttrSize[ATTR_NEST_PLL_BUCKET] = sizeof(ATTR_NEST_PLL_BUCKET_type);
    iv_mapSysAttrSize[ATTR_PAYLOAD_ENTRY] = sizeof(ATTR_PAYLOAD_ENTRY_type);
    iv_mapSysAttrSize[ATTR_RECONFIG_LOOP_TESTS_ENABLE] = sizeof(ATTR_RECONFIG_LOOP_TESTS_ENABLE_type);
    iv_mapSysAttrSize[ATTR_PROC_FABRIC_CORE_FLOOR_RATIO] = sizeof(ATTR_PROC_FABRIC_CORE_FLOOR_RATIO_type);
    iv_mapSysAttrSize[ATTR_SKIP_WAKEUP] = sizeof(ATTR_SKIP_WAKEUP_type);
    iv_mapSysAttrSize[ATTR_RISK_LEVEL] = sizeof(ATTR_RISK_LEVEL_type);
    iv_mapSysAttrSize[ATTR_HDAT_HBRT_SECTION_SIZE] = sizeof(ATTR_HDAT_HBRT_SECTION_SIZE_type);
    iv_mapSysAttrSize[ATTR_CHKSTOP_ANALYSIS_ON_STARTUP] = sizeof(ATTR_CHKSTOP_ANALYSIS_ON_STARTUP_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT32_2] = sizeof(ATTR_SCRATCH_INT32_2_type);
    iv_mapSysAttrSize[ATTR_PHYS_PRES_FAKE_ASSERT] = sizeof(ATTR_PHYS_PRES_FAKE_ASSERT_type);
    iv_mapSysAttrSize[ATTR_PAYLOAD_BASE] = sizeof(ATTR_PAYLOAD_BASE_type);
    iv_mapSysAttrSize[ATTR_PIBMEM_REPAIR1] = sizeof(ATTR_PIBMEM_REPAIR1_type);
    iv_mapSysAttrSize[ATTR_SYSTEM_CORECACHE_DCADJ_DISABLE] = sizeof(ATTR_SYSTEM_CORECACHE_DCADJ_DISABLE_type);
    iv_mapSysAttrSize[ATTR_MRW_HW_MIRRORING_ENABLE] = sizeof(ATTR_MRW_HW_MIRRORING_ENABLE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT32_ARRAY_1] = sizeof(ATTR_SCRATCH_UINT32_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_MSS_VOLT_DDR3_VDDR_INTERCEPT_POST_DRAM_INIT] = sizeof(ATTR_MSS_VOLT_DDR3_VDDR_INTERCEPT_POST_DRAM_INIT_type);
    iv_mapSysAttrSize[ATTR_HYPERVISOR_IPL_SIDE] = sizeof(ATTR_HYPERVISOR_IPL_SIDE_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT8_ARRAY_2] = sizeof(ATTR_SCRATCH_INT8_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_CME_PSTATE_PHANTOM_HALT_ENABLE] = sizeof(ATTR_CME_PSTATE_PHANTOM_HALT_ENABLE_type);
    iv_mapSysAttrSize[ATTR_ASCII_VPD_LX_KEYWORD] = sizeof(ATTR_ASCII_VPD_LX_KEYWORD_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT16_ARRAY_1] = sizeof(ATTR_SCRATCH_INT16_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT64_ARRAY_1] = sizeof(ATTR_SCRATCH_UINT64_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_HTMGT_SAVED_POWER_LIMIT] = sizeof(ATTR_HTMGT_SAVED_POWER_LIMIT_type);
    iv_mapSysAttrSize[ATTR_PIBMEM_REPAIR0] = sizeof(ATTR_PIBMEM_REPAIR0_type);
    iv_mapSysAttrSize[ATTR_FABRIC_TO_PHYSICAL_NODE_MAP] = sizeof(ATTR_FABRIC_TO_PHYSICAL_NODE_MAP_type);
    iv_mapSysAttrSize[ATTR_BLOCK_SPEC_DECONFIG] = sizeof(ATTR_BLOCK_SPEC_DECONFIG_type);
    iv_mapSysAttrSize[ATTR_CALCULATED_MAX_SYS_POWER_EXCLUDING_GPUS] = sizeof(ATTR_CALCULATED_MAX_SYS_POWER_EXCLUDING_GPUS_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT32_ARRAY_1] = sizeof(ATTR_SCRATCH_INT32_ARRAY_1_type);
    iv_mapSysAttrSize[ATTR_ULTRA_TURBO_FREQ_MHZ] = sizeof(ATTR_ULTRA_TURBO_FREQ_MHZ_type);
    iv_mapSysAttrSize[ATTR_HWAS_STATE] = sizeof(ATTR_HWAS_STATE_type);
    iv_mapSysAttrSize[ATTR_KEY_CLEAR_REQUEST] = sizeof(ATTR_KEY_CLEAR_REQUEST_type);
    iv_mapSysAttrSize[ATTR_HYPERVISOR_IPL_DESTINATION] = sizeof(ATTR_HYPERVISOR_IPL_DESTINATION_type);
    iv_mapSysAttrSize[ATTR_LMB_SIZE] = sizeof(ATTR_LMB_SIZE_type);
    iv_mapSysAttrSize[ATTR_HB_SETTINGS] = sizeof(ATTR_HB_SETTINGS_type);
    iv_mapSysAttrSize[ATTR_FREQ_CORE_CEILING_MHZ] = sizeof(ATTR_FREQ_CORE_CEILING_MHZ_type);
    iv_mapSysAttrSize[ATTR_SGPE_PHANTOM_HALT_ENABLE] = sizeof(ATTR_SGPE_PHANTOM_HALT_ENABLE_type);
    iv_mapSysAttrSize[ATTR_NVDIMM_ENCRYPTION_KEYS_ANCHOR] = sizeof(ATTR_NVDIMM_ENCRYPTION_KEYS_ANCHOR_type);
    iv_mapSysAttrSize[ATTR_NVDIMM_AUTO_ARM] = sizeof(ATTR_NVDIMM_AUTO_ARM_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT16_2] = sizeof(ATTR_SCRATCH_INT16_2_type);
    iv_mapSysAttrSize[ATTR_FABRIC_ADDR_EXTENSION_GROUP_ID] = sizeof(ATTR_FABRIC_ADDR_EXTENSION_GROUP_ID_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT64_ARRAY_2] = sizeof(ATTR_SCRATCH_UINT64_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_ORIG_FIR_SETTINGS_ACTION0] = sizeof(ATTR_ORIG_FIR_SETTINGS_ACTION0_type);
    iv_mapSysAttrSize[ATTR_HDAT_RSV_MEM_NUM_SECTIONS] = sizeof(ATTR_HDAT_RSV_MEM_NUM_SECTIONS_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT32_ARRAY_2] = sizeof(ATTR_SCRATCH_UINT32_ARRAY_2_type);
    iv_mapSysAttrSize[ATTR_VTPM_ENABLED] = sizeof(ATTR_VTPM_ENABLED_type);
    iv_mapSysAttrSize[ATTR_MIN_FREQ_MHZ] = sizeof(ATTR_MIN_FREQ_MHZ_type);
    iv_mapSysAttrSize[ATTR_ORDINAL_ID] = sizeof(ATTR_ORDINAL_ID_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_UINT8_1] = sizeof(ATTR_SCRATCH_UINT8_1_type);
    iv_mapSysAttrSize[ATTR_CEC_IPL_TYPE] = sizeof(ATTR_CEC_IPL_TYPE_type);
    iv_mapSysAttrSize[ATTR_SOCKET_POWER_NOMINAL] = sizeof(ATTR_SOCKET_POWER_NOMINAL_type);
    iv_mapSysAttrSize[ATTR_SCRATCH_INT8_ARRAY_1] = sizeof(ATTR_SCRATCH_INT8_ARRAY_1_type);

    #undef TARG_FN
}

}// namespace TARGETING

